pub struct AliyunSmsConfig {
pub access_key_id: String,
pub access_key_secret: String,
pub sign_name: String,
pub domain: Option<String>,
pub region_id: Option<String>,
pub version: Option<String>,
}Fields
access_key_id: Stringaccess_key_secret: Stringsign_name: Stringdomain: Option<String>region_id: Option<String>version: Option<String>Trait Implementations
Sourceimpl Clone for AliyunSmsConfig
impl Clone for AliyunSmsConfig
Sourcefn clone(&self) -> AliyunSmsConfig
fn clone(&self) -> AliyunSmsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AliyunSmsConfig
impl Debug for AliyunSmsConfig
Sourceimpl<'de> Deserialize<'de> for AliyunSmsConfig
impl<'de> Deserialize<'de> for AliyunSmsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AliyunSmsConfig
impl JsonSchema for AliyunSmsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AliyunSmsConfig
impl RefUnwindSafe for AliyunSmsConfig
impl Send for AliyunSmsConfig
impl Sync for AliyunSmsConfig
impl Unpin for AliyunSmsConfig
impl UnwindSafe for AliyunSmsConfig