pub struct SmsConfig {
pub aliyun: Option<AliyunSmsConfig>,
}Fields
aliyun: Option<AliyunSmsConfig>Trait Implementations
Sourceimpl Configurable for SmsConfig
impl Configurable for SmsConfig
Sourcefn config_prefix() -> &'static str
fn config_prefix() -> &'static str
Prefix used to read toml configuration.
If you need to load external configuration, you need to rewrite this method
Sourceimpl<'de> Deserialize<'de> for SmsConfig
impl<'de> Deserialize<'de> for SmsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SmsConfig
impl JsonSchema for SmsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SmsConfig
impl RefUnwindSafe for SmsConfig
impl Send for SmsConfig
impl Sync for SmsConfig
impl Unpin for SmsConfig
impl UnwindSafe for SmsConfig